@@ -3,13 +3,9 @@ from viset.dataset import Viset
 from viset.show import imshow
 
 if __name__ == '__main__':
-  print 'Creating vision dataset for Caltech256 dataset'
   dbfile = Caltech256().export()
-  print 'Exporting Caltech256 dataset to redistributable HDF5 file "' + dbfile + '"'
-  
-  print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile, asycread=False, datastep=100)
-  for (im,annotation) in db['dataset']:
+  db = Viset(dbfile, async=False, datastep=100)
+  for (im,annotation) in db[0]:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
     imshow(im)
 
