@@ -8,7 +8,7 @@ def main():
   print 'Exporting dataset to redistributable HDF5 file "' + dbfile + '"'
 
   print '[test_ethzshapes]: Displaying all images in "' + dbfile + '"'
-  for (im,annotation) in Viset(dbfile, asyncread=False)[0]:
+  for (im,annotation) in Viset(dbfile, async=False)[0]:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
     imbbox(im,annotation['bbox_xmin'],annotation['bbox_xmax'],annotation['bbox_ymin'],annotation['bbox_ymax'], bboxcaption=annotation['category'])
 
