@@ -6,8 +6,9 @@ def main():
   dbfile = WeizmannHorsesMultiScale().export()
   db = Viset(dbfile, datastep=1, async=False, verbose=True)
   for (im,annotation) in db[0]:
-    imshow(im, title='horses')
-    print annotation['mask']  # FIXME: mask image should be a viset type
+    imshow(im, title=annotation['category'])
+    if annotation['mask'] is not None:
+		imshow(annotation['mask'], title='mask')
     
 if __name__ == '__main__':
   main()
