@@ -1,24 +1,23 @@
 import tables
 import os
 from os import path
-import viset.download
-from viset.dataset import CategorizationViset, ImageArchiveViset
+from viset.dataset import CategorizationViset
 
-class Caltech(CategorizationViset, ImageArchiveViset):
+class Caltech(CategorizationViset):
     def export(self, redo=False):
         # Create empty database
         self.create()
 
         # Fetch data necessary to initial construction
-        viset.download.cache_and_extract(self.URL, self.cachedir, sha1=self.SHA1)              
-            
+        pkgdir = self.dbcache.get(self.URL, sha1=self.SHA1)
+        
         # Write images to database
         id_img = 0  
-        labeldir = path.join(self.cachedir, self.PATH)      
+        labeldir = path.join(pkgdir, self.PATH)      
         for label in os.listdir(labeldir):
             imdir = path.join(labeldir,label)        
             for im in os.listdir(imdir):
-                self.add_image(id_img, path.join(self.PATH,imdir,im), 1, id_img)
+                self.add_image(id_img, path.join(self.PATH,label,im), 1, id_img, url=self.URL)
                 id_img += 1
         self.write()
 
@@ -33,9 +32,6 @@ class Caltech(CategorizationViset, ImageArchiveViset):
             id_category += 1
         self.write()
         
-        # Add one data package for download
-        self.add_package(self.URL, self.SHA1)
-        
         # Cleanup
         self.close()
         return self.dbfile
