@@ -6,7 +6,7 @@ from os import path
 import shutil
 import viset.download
 import viset.util
-from viset.util import ishdf5, isfile, isarchive, quietprint, setfetched, wasfetched
+from viset.util import ishdf5, isfile, isarchive, quietprint
 import numpy as np 
 import urllib
 import socket
@@ -18,16 +18,13 @@ import viset.types
 import urlparse
 import viset.views 
 import datetime
+from viset.cache import Cache
+
 
 class AboutTable(tables.IsDescription):
     viset = tables.StringCol(256, pos=0)   
     name = tables.StringCol(256, pos=1)   
     version = tables.Int64Col(pos=2)   
-    imcodec = tables.StringCol(256, pos=4)  # hint for binary decode
-
-class PackageTable(tables.IsDescription):
-    url = tables.StringCol(512, pos=1)   
-    sha1 = tables.StringCol(512, pos=1)     
 
 class SplitTable(tables.IsDescription):
     split0 = tables.UInt8Col(pos=0)   
@@ -48,32 +45,29 @@ class ImageTable(tables.IsDescription):
     n_anno = tables.Int32Col(pos=3)   
     
 class Viset(object):
-    cacheroot = viset.util.cacheroot()
-    cachedir = None
     dburl = None   # remote file
     dbfile = None  # local file in cache
     verbose = None
     dbobj = None  # database object
     dbview = None  # active database view from task
-    _impkg = None   # overloaded for create
+    dbcache = None # cache object
     _viewname = None  # overloaded for create
-    _imcodec = 'universal'  # overloaded for create
     _version = 0 # overloaded for create
     _dbname = None # overloaded for create
     _imrow = None    # fast pytable writes (FIXME)
     _pkgrow = None   # fast pytable writes (FIXME)
     
     
-    def __init__(self, dbfile=dbfile, task=None, strategy=None, kfold=0, datastep=1, async=True, verbose=False):
+    def __init__(self, dbfile=dbfile, task=None, strategy=None, kfold=0, datastep=1, async=True, verbose=False, cacheroot=None):
         if dbfile is not None:
             self.verbose = verbose            
+            self.dbcache = Cache(verbose=self.verbose, cacheroot=cacheroot)
             self.dbobj = self.open(dbfile)
             self.dbview = self.view(task, async=async)
             self.dbview.split(strategy=strategy, kfold=kfold, datastep=datastep)
-            self.fetch()
         else:
             # empty initialization for subclass create
-            pass
+            self.dbcache = Cache(verbose=True)
 
     def __call__(self):        
         raise IOError('FIXME: this can be used to change the split instead of calling .split()?')
@@ -104,9 +98,7 @@ class Viset(object):
         print 'Dataset name: ' + str(self.name())    
         print 'Database file: ' + self.dbfile
         print 'Database version: ' + str(self.version())
-        print 'Cache root directory: ' + self.cacheroot
-        print 'Cache directory: ' + self.cachedir
-        print 'Image codec: ' + '\'' + self.imcodec() + '\''
+        print 'Cache directory: ' + self.dbcache._cacheroot
         print 'Database views: ' + str(self.list_views())
         print 'Number of images: ' + str(self.num_images())
         print 'Current view: ' + '\'' + self.dbview.name() + '\''
@@ -122,14 +114,18 @@ class Viset(object):
         self.dbview = viset.views.bind(viewname, self).set(async=async).open()
         return self.dbview
         
-    def add_package(self, URL, SHA1):
-        if self._pkgrow is None:
-            self._pkgrow = self.dbobj.root.packages.row            
-        self._pkgrow['url'] = URL
-        self._pkgrow['sha1'] = SHA1
-        self._pkgrow.append()
 
-    def add_image(self, id_img, url, n_anno, id_anno):
+    def add_image(self, id_img, relpath, n_anno, id_anno, url=None, reader=None, id=None):
+        qs = {}
+        if reader is not None:
+            qs['reader'] = reader
+        if id is not None:
+            qs['id'] = id
+        if relpath is not None:
+            qs['item'] = relpath
+        url_fragment = urlparse.unquote(urllib.urlencode(qs))
+        if len(url_fragment) > 0:
+            url = url + '#' + url_fragment
         if self._imrow is None:
             self._imrow = self.dbobj.root.images.row            
         self._imrow['id'] = id_img
@@ -137,7 +133,7 @@ class Viset(object):
         self._imrow['n_anno'] = n_anno
         self._imrow['id_anno'] = id_anno
         self._imrow.append()
-        
+        return (id_img, url, n_anno, id_anno)
         
     def open(self, dbfile):
         # Database location resolution
@@ -147,13 +143,12 @@ class Viset(object):
             raise IOError('invalid database file extension - must be HDF5 (.h5)')                
         if isfile(dbfile):
             dburl = None
-        elif isfile(path.join(self.cacheroot, path.basename(dbfile))):
-            dbfile = path.join(self.cacheroot, path.basename(dbfile))
+        elif isfile(self.dbcache.abspath(path.basename(dbfile))):
+            dbfile = self.dbcache.abspath(path.basename(dbfile))
             dburl = None
         elif isurl(dbfile):
             dburl = dbfile
-            dbfile = path.join(self.cachedir, path.basename(dburl))
-            viset.download.download(dburl, dbfile, verbose=self.verbose)
+            dbfile = self.dbcache.get(dburl)
         else:
             dbfile = None
             dburl = None
@@ -168,29 +163,19 @@ class Viset(object):
             print 'Invalid database file "' + str(dbfile) + '"'
             raise      
 
-        # Initialize cache
-        dbname = dbobj.root.about[0]['name']
-        cachedir = path.join(self.cacheroot, dbname) 
-        if not path.exists(cachedir):
-            os.makedirs(cachedir)
-
         # Update class properties
         self.dbobj = dbobj
         self.dbfile = dbfile
         self.dburl = dburl
-        self.cachedir = cachedir
         return self.dbobj
     
-    def create(self):
-        # Initialize cache
-        cachedir = path.join(self.cacheroot, self._dbname)      
-        if not path.exists(cachedir):
-            os.makedirs(cachedir)
-        dbfile = path.join(self.cacheroot, self._dbname+'.h5')
+    def create(self, view=_viewname):
+        dbfile = self.dbcache.abspath(self._dbname+'.h5')
         dburl = None
-
+        quietprint('Creating viset "' + dbfile + '"', self.verbose)                
+        
         # Format new dataset
-        self.dbobj = self.format(dbfile, self._dbname, self._viewname, self._impkg, self._version, self._imcodec)
+        self.dbobj = self.format(dbfile, self._dbname, view, self._version)
 
         # Create default view
         self.dbview = self.view()
@@ -198,14 +183,12 @@ class Viset(object):
         # Update class properties
         self.dbfile = dbfile
         self.dburl = dburl
-        self.cachedir = cachedir
         
     def close(self):
         self.dbobj.close()
 
     def delete(self):
-        quietprint('Deleting all cached data in "' + self.cachedir + '" for dataset "' + self.dbfile + '"', self.verbose)
-        shutil.rmtree(self.cachedir)
+        self.dbcache.delete()
 
     def name(self):
         return self.dbobj.root.about[0]['name']
@@ -213,9 +196,6 @@ class Viset(object):
     def version(self):
         return self.dbobj.root.about[0]['version']
 
-    def imcodec(self):
-        return self.dbobj.root.about[0]['imcodec']
-  
     def about(self):
         return self.dbobj.root.about[0]
 
@@ -236,7 +216,7 @@ class Viset(object):
   
     def urlquery(self, url):
         """query database by using querystring format 'http://domain.com/mydb.h5?table=x&row=y&field=z'"""
-        if not isurl(url):
+        if not viset.util.isurl(url):
             ValueError('Invalid URL \'' + url + '\'')
         p = urlparse.urlsplit(url)
         p = urlparse.parse_qs(p[3])
@@ -262,11 +242,10 @@ class Viset(object):
             return self.dbobj.getNode(table)[row][field] 
    
     
-    def format(self, dbfile, dbname, dbviewname=[], dbimpkg='url', dbversion=0, dbimcodec='universal'):
+    def format(self, dbfile, dbname, dbviewname=[], dbversion=0):
         # HDF5 file structure
         self.dbobj = tables.open_file(dbfile, mode = "w", title = dbname)
         tbl_about = self.dbobj.create_table(self.dbobj.root, 'about', AboutTable, expectedrows=1, title='About')    
-        tbl_packagse = self.dbobj.create_table(self.dbobj.root, 'packages', PackageTable, title='Packages', expectedrows=10)
         tbl_splits = self.dbobj.create_table(self.dbobj.root, 'splits', SplitTable, title='Splits', expectedrows=1000000)
         tbl_images = self.dbobj.create_table(self.dbobj.root, 'images', ImageTable, title='Images', filters=tables.Filters(complevel=6), expectedrows=1000000)
     
@@ -282,32 +261,12 @@ class Viset(object):
         r['viset'] = 'http://www.visym.com'
         r['version'] = dbversion
         r['name'] = dbname
-        r['imcodec'] = dbimcodec
         r.append()
 
         # Return newly created database for writing
         self.dbobj.flush()
         return self.dbobj
 
-    def fetch(self):
-        """Fetch packages stored in package table"""
-        if self.dbobj.root.packages.nrows > 0:
-            if not self.iscached():
-                packages = self.dbobj.root.packages.iterrows()
-                for pkg in packages:
-                    if isfile(path.join(self.cachedir, path.basename(pkg['url']))):
-                        # already cached (from export)
-                        continue
-                    elif isarchive(pkg['url']):
-                        viset.download.extract_and_cleanup(pkg['url'], self.cachedir, sha1=pkg['sha1'], verbose=self.verbose)      
-                        os.remove(path.join(self.cachedir, path.basename(pkg['url'])))
-                    else:
-                        viset.download.download(pkg['url'], path.join(self.cachedir, path.basename(pkg['url'])), sha1=pkg['sha1'], verbose=self.verbose)                              
-                setfetched(self.cachedir)
-
-    def iscached(self):
-        wasfetched(self.cachedir)
-
         
 class CategorizationViset(Viset):
     _viewname = 'Categorization'
@@ -321,13 +280,5 @@ class DetectionViset(Viset):
 class SegmentationViset(Viset):
     _viewname = 'Segmentation'
     
-class ImageArchiveViset(Viset):
-    _impkg = 'package'
-
-class UrlViset(Viset):
-    _impkg = 'url'    
-
-class CustomImageViset(Viset):
-    _imcodec = 'custom'
 
 
