@@ -2,26 +2,25 @@ import tables
 import os
 from os import path
 import viset.download
-from viset.dataset import CategorizationViset, UrlViset
-from viset.util import wascached
+from viset.dataset import CategorizationViset
 
-class ImageNet(CategorizationViset, UrlViset):
+class ImageNet(CategorizationViset):
     def export(self, redo=False):            
         # Create empty database
         self.create()
 
         # Fetch textfile for construction
-        viset.download.cache_and_extract(self.URL, self.cachedir, sha1=self.SHA1)              
+        pkgdir = self.dbcache.get(self.URL, sha1=self.SHA1)        
 
         # Write images (chunked)
         dbview = self.view()          
         id_img = 0
-        txtfile = path.join(self.cachedir,self.TXTFILE)
+        txtfile = path.join(pkgdir,self.TXTFILE)
         for line in open(txtfile,'r'):
             try:
                 name, url = line.rstrip().split('\t')
                 id_wordnet, suffix = name.rstrip().split('_')      
-                self.add_image(id_img, url, 1, id_img)  # id_anno=id_img                            
+                self.add_image(id_img, None, 1, id_img, url=url)  # id_anno=id_img                            
                 id_img += 1
             except:
                 print '[viset.imagenet]: Warning: Ignoring malformed line "' + line[0:64] + ' ..."'
@@ -29,7 +28,7 @@ class ImageNet(CategorizationViset, UrlViset):
                 
         # Write annotations (chunked)
         id_anno = 0
-        txtfile = path.join(self.cachedir,self.TXTFILE)
+        txtfile = path.join(pkgdir,self.TXTFILE)
         for line in open(txtfile,'r'):
             try:
                 name, url = line.rstrip().split('\t')
